couchdb.client.Document

Package couchdb :: Module client :: Class Document |

# Class Document

    object --+
             |
          dict --+
                 |
                Document

Representation of a document in the database.

This is basically just a dictionary with the two additional properties id and rev, which contain the document ID and revision, respectively.

Instance Methods
__repr__(self) repr(x) |
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
basestring | id The document ID.
basestring | rev The document revision.
Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

Property Details

### id The document ID. Get Method: unreachable.id(self) - The document ID. Type: basestring

### rev The document revision. Get Method: unreachable.rev(self) - The document revision. Type: basestring